==> jc-1.4.0.tar.gz: gnu/xml/util/Resolver.h <==
// public class gnu.xml.util.Resolver

// class file dependencies
// @dep_class 1ab5fcb2cc865fc gnu_xml_util_Resolver
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_util_Resolver_H_
#define _JC_gnu_xml_util_Resolver_H_

// Forward structure declarations
struct _jc_java_io_File$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Dictionary$object;
struct _jc_org_xml_sax_InputSource$object;

// Typedefs
typedef struct _jc_gnu_xml_util_Resolver$sub_refs	_jc_gnu_xml_util_Resolver$sub_refs;
typedef struct _jc_gnu_xml_util_Resolver$sub_nonrefs	_jc_gnu_xml_util_Resolver$sub_nonrefs;
typedef struct _jc_gnu_xml_util_Resolver$refs	_jc_gnu_xml_util_Resolver$refs;
typedef struct _jc_gnu_xml_util_Resolver$nonrefs	_jc_gnu_xml_util_Resolver$nonrefs;
typedef struct _jc_gnu_xml_util_Resolver$object	_jc_gnu_xml_util_Resolver$object;

typedef const struct _jc_gnu_xml_util_Resolver$vmethods	_jc_gnu_xml_util_Resolver$vmethods;
typedef const struct _jc_gnu_xml_util_Resolver$vtable	_jc_gnu_xml_util_Resolver$vtable;
typedef const struct _jc_gnu_xml_util_Resolver$vtype	_jc_gnu_xml_util_Resolver$vtype;

// Constructors
extern void _jc_gnu_xml_util_Resolver$method$_init$9147abe207320dfe(_jc_env *, struct _jc_gnu_xml_util_Resolver$object *, struct _jc_java_util_Dictionary$object *);

// Virtual methods
extern struct _jc_org_xml_sax_InputSource$object *_jc_gnu_xml_util_Resolver$method$resolveEntity$dc649396337500d5(_jc_env *, struct _jc_gnu_xml_util_Resolver$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_util_Resolver$method_info$resolveEntity$dc649396337500d5;

// Static methods
extern void _jc_gnu_xml_util_Resolver$method$addDirectoryMapping$31a87eeb1be41f66(_jc_env *, struct _jc_java_util_Dictionary$object *, struct _jc_object_array *, struct _jc_java_io_File$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_util_Resolver$method$fileNameToURL$f9553da090155e6b(_jc_env *, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_util_Resolver$method$fileToURL$ec366e2bf677eb3f(_jc_env *, struct _jc_java_io_File$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_util_Resolver$method$getEncoding$c0ec13f9b70216d8(_jc_env *, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_util_Resolver$method$getURL$1f54df6b7c381f6f(_jc_env *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_gnu_xml_util_Resolver$vmethods {
	struct _jc_org_xml_sax_InputSource$object	*(*resolveEntity$dc649396337500d5)(_jc_env *, struct _jc_gnu_xml_util_Resolver$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_gnu_xml_util_Resolver$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_util_Resolver$vmethods	gnu_xml_util_Resolver;
};

// Vtype
struct _jc_gnu_xml_util_Resolver$vtype {
	_jc_type			type;
	_jc_gnu_xml_util_Resolver$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_util_Resolver$sub_refs {
	struct _jc_java_util_Dictionary$object	*pubidMapping;
};

// Reference instance fields (object)
struct _jc_gnu_xml_util_Resolver$refs {
    _jc_gnu_xml_util_Resolver$sub_refs	gnu_xml_util_Resolver;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_util_Resolver$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_util_Resolver$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_util_Resolver$sub_nonrefs	gnu_xml_util_Resolver;
};

// Object instance structure
struct _jc_gnu_xml_util_Resolver$object {
	_jc_gnu_xml_util_Resolver$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_util_Resolver$vtype	*vtype;
	_jc_gnu_xml_util_Resolver$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_util_Resolver$vtype _jc_gnu_xml_util_Resolver$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_util_Resolver, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_util_Resolver$class_object;

#endif	/* _JC_gnu_xml_util_Resolver_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/util/Resolver.h <==
// public class gnu.xml.util.Resolver

// class file dependencies
// @dep_class 1ab5fcb2cc865fc gnu_xml_util_Resolver
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_util_Resolver_H_
#define _JC_gnu_xml_util_Resolver_H_

// Forward structure declarations
struct _jc_java_io_File$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Dictionary$object;
struct _jc_org_xml_sax_InputSource$object;

// Typedefs
typedef struct _jc_gnu_xml_util_Resolver$sub_refs	_jc_gnu_xml_util_Resolver$sub_refs;
typedef struct _jc_gnu_xml_util_Resolver$sub_nonrefs	_jc_gnu_xml_util_Resolver$sub_nonrefs;
typedef struct _jc_gnu_xml_util_Resolver$refs	_jc_gnu_xml_util_Resolver$refs;
typedef struct _jc_gnu_xml_util_Resolver$nonrefs	_jc_gnu_xml_util_Resolver$nonrefs;
typedef struct _jc_gnu_xml_util_Resolver$object	_jc_gnu_xml_util_Resolver$object;

typedef const struct _jc_gnu_xml_util_Resolver$vmethods	_jc_gnu_xml_util_Resolver$vmethods;
typedef const struct _jc_gnu_xml_util_Resolver$vtable	_jc_gnu_xml_util_Resolver$vtable;
typedef const struct _jc_gnu_xml_util_Resolver$vtype	_jc_gnu_xml_util_Resolver$vtype;

// Constructors
extern void _jc_gnu_xml_util_Resolver$method$_init$9147abe207320dfe(_jc_env *, struct _jc_gnu_xml_util_Resolver$object *, struct _jc_java_util_Dictionary$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_org_xml_sax_InputSource$object *_jc_gnu_xml_util_Resolver$method$resolveEntity$dc649396337500d5(_jc_env *, struct _jc_gnu_xml_util_Resolver$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_util_Resolver$method_info$resolveEntity$dc649396337500d5;

// Static methods
extern void _jc_gnu_xml_util_Resolver$method$addDirectoryMapping$31a87eeb1be41f66(_jc_env *, struct _jc_java_util_Dictionary$object *, struct _jc_object_array *, struct _jc_java_io_File$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_util_Resolver$method$fileNameToURL$f9553da090155e6b(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_util_Resolver$method$fileToURL$ec366e2bf677eb3f(_jc_env *, struct _jc_java_io_File$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_util_Resolver$method$getEncoding$c0ec13f9b70216d8(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_util_Resolver$method$getURL$1f54df6b7c381f6f(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_xml_util_Resolver$vmethods {
	struct _jc_org_xml_sax_InputSource$object	*(*resolveEntity$dc649396337500d5)(_jc_env *, struct _jc_gnu_xml_util_Resolver$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_util_Resolver$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_util_Resolver$vmethods	gnu_xml_util_Resolver;
};

// Vtype
struct _jc_gnu_xml_util_Resolver$vtype {
	_jc_type			type;
	_jc_gnu_xml_util_Resolver$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_util_Resolver$sub_refs {
	struct _jc_java_util_Dictionary$object	*pubidMapping;
};

// Reference instance fields (object)
struct _jc_gnu_xml_util_Resolver$refs {
    _jc_gnu_xml_util_Resolver$sub_refs	gnu_xml_util_Resolver;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_util_Resolver$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_util_Resolver$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_util_Resolver$sub_nonrefs	gnu_xml_util_Resolver;
};

// Object instance structure
struct _jc_gnu_xml_util_Resolver$object {
	_jc_gnu_xml_util_Resolver$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_util_Resolver$vtype	*vtype;
	_jc_gnu_xml_util_Resolver$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_util_Resolver$vtype _jc_gnu_xml_util_Resolver$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_util_Resolver, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_util_Resolver$class_object;

#endif	/* _JC_gnu_xml_util_Resolver_H_ */
